pub struct MultiStarkKeygenBuilder<SC: StarkProtocolConfig> {
pub config: SC,
/* private fields */
}Expand description
Stateful builder to create multi-stark proving and verifying keys for system of multiple RAPs with multiple multi-matrix commitments
Fields
config: SCImplementations
Sourceimpl<SC: StarkProtocolConfig> MultiStarkKeygenBuilder<SC>
impl<SC: StarkProtocolConfig> MultiStarkKeygenBuilder<SC>
pub fn new(config: SC) -> Self
pub fn params(&self) -> &SystemParams
Sourcepub fn add_air(&mut self, air: AirRef<SC>) -> usize
pub fn add_air(&mut self, air: AirRef<SC>) -> usize
Default way to add a single Interactive AIR.
Returns air_id
pub fn add_required_air(&mut self, air: AirRef<SC>) -> usize
Sourcepub fn generate_pk(self) -> Result<MultiStarkProvingKey<SC>, KeygenError>
pub fn generate_pk(self) -> Result<MultiStarkProvingKey<SC>, KeygenError>
Consume the builder and generate proving key. The verifying key can be obtained from the proving key.